Class: LogglyOutputBuffred
- Inherits:
-
Fluent::BufferedOutput
- Object
- Fluent::BufferedOutput
- LogglyOutputBuffred
- Defined in:
- lib/fluent/plugin/out_loggly_buffered.rb
Overview
Copyright © 2012 Patrik Antonsson
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements. See the NOTICE file
distributed with this work for additional information
regarding copyright ownership. The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied. See the License for the
specific language governing permissions and limitations
under the License.
Instance Method Summary collapse
- #configure(conf) ⇒ Object
- #format(tag, time, record) ⇒ Object
- #shutdown ⇒ Object
- #start ⇒ Object
- #write(chunk) ⇒ Object
Instance Method Details
#configure(conf) ⇒ Object
33 34 35 36 |
# File 'lib/fluent/plugin/out_loggly_buffered.rb', line 33 def configure(conf) super $log.debug "Loggly url #{@loggly_url}" end |
#format(tag, time, record) ⇒ Object
50 51 52 |
# File 'lib/fluent/plugin/out_loggly_buffered.rb', line 50 def format(tag, time, record) [tag, time, record].to_msgpack end |
#shutdown ⇒ Object
46 47 48 |
# File 'lib/fluent/plugin/out_loggly_buffered.rb', line 46 def shutdown super end |
#start ⇒ Object
38 39 40 41 42 43 44 |
# File 'lib/fluent/plugin/out_loggly_buffered.rb', line 38 def start super require 'net/http/persistent' @uri = URI @loggly_url @http = Net::HTTP::Persistent.new 'fluentd-plugin-loggly', :ENV @http.headers['Content-Type'] = 'text' end |
#write(chunk) ⇒ Object
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/fluent/plugin/out_loggly_buffered.rb', line 54 def write(chunk) records = [] chunk.msgpack_each {|tag,time,record| record['timestamp'] ||= Time.at(time).iso8601 if @output_include_time records.push(Yajl::Encoder.encode(record)) } $log.debug "#{records.length} records sent" post = Net::HTTP::Post.new @uri.path post.body = records.join("\n") begin response = @http.request @uri, post $log.debug "HTTP Response code #{response.code}" $log.error response.body if response.code != "200" rescue $log.error "Error connecting to loggly verify the url #{@loggly_url}" end end |